document_matches_entity

Function document_matches_entity 

pub fn document_matches_entity(entity: &Entity, doc: &OntologyDocument) -> bool
Whether entity is owned by doc via exact ontology id / ontology IRI equality.

Does not use entity-IRI starts_with(base_iri) — that is ambiguous when multiple documents have nested bases. Use document_for_entity to resolve ownership among a set.