Workspace configuration directory resolution (.strixonomy primary, .ontocore legacy).
Constants
- CACHE_
SUBDIR - Relative cache directory under the config dir.
- CONFIG_
DIR - Primary workspace config directory (v0.27+).
- DIAGNOSTICS_
FILE - Diagnostics config filename under the config dir.
- LEGACY_
CONFIG_ DIR - Legacy OntoCore config directory (accepted through at least 1.0).
- LEGACY_
PLUGIN_ DISABLED_ REL - Legacy disabled-plugins state file.
- LEGACY_
PLUGIN_ OUT_ REL - Legacy plugin export directory.
- PLUGINS_
SUBDIR - Relative plugins directory under the config dir.
- PLUGIN_
DISABLED_ REL - Disabled-plugins state file (relative to workspace).
- PLUGIN_
OUT_ REL - Default plugin export directory (relative to workspace).
Functions
- cache_
dir - Cache root under the workspace.
- diagnostics_
config_ path - Diagnostics.toml path.
- plugin_
search_ dirs - All plugin directories to scan (primary first, then legacy if distinct and present).
- plugins_
dir - Primary plugins directory path (may not exist yet).
- resolve_
config_ path - Resolve
{workspace}/.strixonomy/{leaf}preferring an existing primary path, else an existing legacy.ontocore/{leaf}, else the primary path for writes. - resolve_
dotted_ config_ path - Like
resolve_config_pathbut for a relative path that already includes the config dir prefix (e.g..strixonomy/cache).